@@ -3,11 +3,10 @@
 
 # djk/select_pipe.py
 
-from pjk.base import Pipe, Usage, ParsedToken, UsageError
-
-class SelectFields(Pipe):
-    deep_copyable: bool = True
+from pjk.components import DeepCopyPipe
+from pjk.usage import Usage, ParsedToken, UsageError
 
+class SelectFields(DeepCopyPipe):
     @classmethod
     def usage(cls):
         usage = Usage(
