@@ -2,9 +2,8 @@
 # Copyright 2024 Mike Schultz
 
 from typing import Callable
-import os
-import gzip
-from pjk.base import Source, Sink, ParsedToken
+from pjk.components import Source, Sink
+from pjk.usage import ParsedToken
 from pjk.common import ComponentFactory
 from pjk.sinks.stdout import StdoutSink
 from pjk.sinks.json_sink import JsonSink
@@ -12,29 +11,29 @@ from pjk.sinks.devnull import DevNullSink
 from pjk.sinks.graph import GraphSink
 from pjk.sinks.csv_sink import CSVSink
 from pjk.sinks.tsv_sink import TSVSink
-from pjk.sinks.ddb import DDBSink
-from pjk.sinks.dir_sink import DirSink
-from pjk.sinks.s3_sink import S3Sink
 from pjk.sinks.expect import ExpectSink
 from pjk.sinks.format_sink import FormatSink
+from pjk.sinks.create_sink import CreateSink
 from pjk.sinks.user_sink_factory import UserSinkFactory
 
 COMPONENTS = {
         '-': StdoutSink,
         'devnull': DevNullSink,
         'graph': GraphSink,
-        'ddb': DDBSink,
         'json': JsonSink,
         'csv': CSVSink,
         'tsv': TSVSink,
+        'create': CreateSink
         }
 
 class SinkFactory(ComponentFactory):
     def __init__(self):
-        super().__init__(COMPONENTS, 'sink')   
+        super().__init__(COMPONENTS)
+
+    def get_comp_type_name(self):
+        return 'sink'
 
     def create(self, token: str) -> Callable[[Source], Sink]:
-        token = token.strip()
         ptok = ParsedToken(token)
 
         # non-usage sink (bind incompatible)
@@ -45,8 +44,10 @@ class SinkFactory(ComponentFactory):
             sink = UserSinkFactory.create(ptok)
             if sink:
                 return sink
+            else:
+                return None
         
-        sink_cls = self.components.get(ptok.pre_colon)
+        sink_cls = self.get_component_class(ptok.pre_colon)
         if sink_cls and not issubclass(sink_cls, FormatSink):
             usage = sink_cls.usage()
             usage.bind(ptok)
