@@ -2,21 +2,15 @@
 # Copyright 2024 Mike Schultz
 
 import sys
-from pjk.base import Source, NoBindUsage
-from pjk.sources.format_usage import FormatUsage
+from pjk.usage import NoBindUsage
+from pjk.components import Source
+from pjk.sources.format_source import FormatSource
 from pjk.sources.lazy_file import LazyFile
 
 
-class SQLSource(Source):
-    is_format = True
-
-    @classmethod
-    def usage(cls):
-        return FormatUsage(
-            "sql",
-            component_class=cls,
-            desc_override="SQL source. Emits SQL in single record in 'query' field."
-        )
+class SQLSource(FormatSource):
+    extension = 'sql'
+    desc_override = "SQL source. Emits SQL in single record in 'query' field."
 
     def __init__(self, lazy_file: LazyFile):
         self.lazy_file = lazy_file
